===============
aichclient
===============

Async http(s) clickhouse client for python 3.6+ with types converting in both directions and streaming support

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    install
    api
